Index: channels/chan_iax2.c
===================================================================
RCS file: /usr/cvsroot/asterisk/channels/chan_iax2.c,v
retrieving revision 1.287
diff -u -r1.287 chan_iax2.c
--- channels/chan_iax2.c	15 May 2005 23:26:45 -0000	1.287
+++ channels/chan_iax2.c	17 May 2005 19:08:38 -0000
@@ -8862,6 +8862,81 @@
 	return -1;
 }
 
+static char *function_iaxpeer(struct ast_channel *chan, char *cmd, char *data, char *buf, size_t len)
+{
+    char *ret = NULL;
+	struct iax2_peer *peer;
+	char *peername, *colname;
+	char iabuf[INET_ADDRSTRLEN];
+
+	if ((peername = ast_strdupa(data))) {
+		if ((colname = strchr(peername, ':'))) {
+			*colname = '\0';
+			colname++;
+		} else {
+			colname = "ip";
+		}
+		if ((peer = find_peer(peername, 1))) {
+			if (!strcasecmp(colname, "ip")) {
+				ast_copy_string(buf, peer->addr.sin_addr.s_addr ? ast_inet_ntoa(iabuf, sizeof(iabuf), peer->addr.sin_addr) : "", len);
+			} else  if (!strcasecmp(colname, "mailbox")) {
+				ast_copy_string(buf, peer->mailbox, len);
+			} else  if (!strcasecmp(colname, "context")) {
+				ast_copy_string(buf, peer->context, len);
+			} else  if (!strcasecmp(colname, "expire")) {
+				snprintf(buf, len, "%d", peer->expire);
+			} else  if (!strcasecmp(colname, "dynamic")) {
+				ast_copy_string(buf, (ast_test_flag(peer, IAX_DYNAMIC) ? "yes" : "no"), len);
+			} else  if (!strcasecmp(colname, "callerid_name")) {
+				ast_copy_string(buf, peer->cid_name, len);
+			} else  if (!strcasecmp(colname, "callerid_num")) {
+				ast_copy_string(buf, peer->cid_num, len);
+			} else  if (!strcasecmp(colname, "codecs")) {
+				ast_getformatname_multiple(buf, len -1, peer->capability);
+			} else  if (!strncasecmp(colname, "codec[", 6)) {
+				char *codecnum, *ptr;
+				int index = 0, codec = 0;
+
+				codecnum = strchr(colname, '[');
+				*codecnum = '\0';
+				codecnum++;
+				if ((ptr = strchr(codecnum, ']'))) {
+					*ptr = '\0';
+				}
+				index = atoi(codecnum);
+				if((codec = ast_codec_pref_index(&peer->prefs, index))) {
+					ast_copy_string(buf, ast_getformatname(codec), len);
+				}
+			}
+			ret = buf;
+		}
+	} else {
+		ast_log(LOG_ERROR, "Memory Error!\n");
+	}
+
+	return ret;
+}
+
+struct ast_custom_function iaxpeer_function = {
+    .name = "IAXPEER",
+    .synopsis = "Gets IAX Peer INFO",
+    .syntax = "IAXPEER(<peername>[:col])",
+    .read = function_iaxpeer,
+	.desc = "Valid Columns Include:\n"
+	"- ip (default)          The IP of the peer.\n"
+	"- mailbox               The configured mail box.\n"
+	"- context               The configured context.\n"
+	"- expire                The epoch time of the next expire.\n"
+	"- dynamic               Is it dynamic? (yes/no).\n"
+	"- callerid_name         The configured caller id name.\n"
+	"- callerid_num          The configured caller id number.\n"
+	"- codecs                The configured codecs.\n"
+	"- codec[x]              Prefered codec index number 'x' (0 being first).\n"
+	"\n"
+	""
+};
+
+
 /*--- iax2_devicestate: Part of the device state notification system ---*/
 static int iax2_devicestate(void *data) 
 {
@@ -8968,6 +9043,7 @@
 	ast_mutex_destroy(&userl.lock);
 	ast_mutex_destroy(&peerl.lock);
 	ast_mutex_destroy(&waresl.lock);
+	ast_custom_function_unregister(&iaxpeer_function);
 	return __unload_module();
 }
 
@@ -8983,6 +9059,8 @@
 	
 	struct ast_netsock *ns;
 	struct sockaddr_in sin;
+	
+	ast_custom_function_register(&iaxpeer_function);
 
 	iax_set_output(iax_debug_output);
 	iax_set_error(iax_error_output);
